# KNOW YOUR HTTP well. SPECS

concept/identifier | description | spec
------------------ | :---------- | :---
`Cookie` | "This document specifies a way to create a stateful session with Hypertext Transfer Protocol (HTTP) requests and responses." | [RFC2965](http://tools.ietf.org/html/rfc2965), [RFC2109](http://tools.ietf.org/html/rfc2109)
`HTTP Signatures` | "This document describes a way to add origin authentication, message integrity, and replay resistance to HTTP requests.  It is intended to be used over the HTTPS protocol." | [draft-cavage-http-signatures](http://tools.ietf.org/html/draft-cavage-http-signatures)
`HTTP` | "The Hypertext Transfer Protocol (HTTP) is an application-level protocol for distributed, collaborative, hypermedia information systems." | [RFC2616](http://tools.ietf.org/html/rfc2616)
`HTTPbis auth` | "This document defines HTTP/1.1 access control and authentication." | [draft-ietf-httpbis-p7-auth](http://tools.ietf.org/html/draft-ietf-httpbis-p7-auth)
`HTTPbis cache` | "HTTP is typically used for distributed information systems, where performance can be improved by the use of response caches." | [draft-ietf-httpbis-p6-cache](http://tools.ietf.org/html/draft-ietf-httpbis-p6-cache)
`HTTP client hints` | "Client Hints can be used as input to proactive content negotiation; just as the Accept header allowed clients to indicate what formats they prefer, Client Hints allow clients to indicate a list of device and agent specific preferences." | [draft-grigorik-http-client-hints](http://tools.ietf.org/html/draft-grigorik-http-client-hints)
`HTTPbis conditional` | "Conditional requests are HTTP requests that include one or more header fields indicating a precondition to be tested before applying the method semantics to the target resource." | [draft-ietf-httpbis-p4-conditional](http://tools.ietf.org/html/draft-ietf-httpbis-p4-conditional)
`HTTPbis messaging` | "The Hypertext Transfer Protocol (HTTP) is an application-level request/response protocol that uses extensible semantics and self-descriptive message payloads for flexible interaction with network-based hypertext information systems." | [draft-ietf-httpbis-p1-messaging](http://tools.ietf.org/html/draft-ietf-httpbis-p1-messaging)
`HTTPbis range` | "Hypertext Transfer Protocol (HTTP) clients often encounter interrupted data transfers as a result of canceled requests or dropped connections." | [draft-ietf-httpbis-p5-range](http://tools.ietf.org/html/draft-ietf-httpbis-p5-range)
`HTTPbis security properties` | "Recent IESG practice dictates that IETF protocols must specify mandatory-to-implement (MTI) security mechanisms, so that all conformant implementations share a common baseline. This document examines all widely deployed HTTP security technologies, and analyzes the trade-offs of each." | [draft-ietf-httpbis-security-properties](http://tools.ietf.org/html/draft-ietf-httpbis-security-properties)
`HTTPbis semantics` | "Each Hypertext Transfer Protocol (HTTP) message is either a request or a response." | [draft-ietf-httpbis-p2-semantics](http://tools.ietf.org/html/draft-ietf-httpbis-p2-semantics)
`IPv4 Address Blocks Reserved for Documentation` | "This document describes three IPv4 address blocks that are provided for use in documentation. " | [RFC5737](http://tools.ietf.org/search/rfc5737)
`LCI` | "This memo defines two new link types that indicate relationships between resources in terms of cache invalidation, along with a HTTP cache-control extension that takes advantage of those relationships to use them to extend response freshness.  Collectively, this is referred to as Linked Cache Invalidation (LCI)." | [draft-nottingham-linked-cache-inv](http://tools.ietf.org/html/draft-nottingham-linked-cache-inv)
`Reserved Top Level DNS Names` | "To reduce the likelihood of conflict and confusion, a few top level domain names are reserved for use in private testing, as examples in documentation, and the like. In addition, a few second level domain names reserved for use as examples are documented." | [RFC2606](http://tools.ietf.org/html/rfc2606)
`The Alternates Header Field` | "This document proposes a header, Alternates, which is intended to provide a common method for Internet-based application protocols to indicate that a particular resource exists in multiple forms." | [draft-ietf-http-alternates](http://tools.ietf.org/html/draft-ietf-http-alternates)
`URI template` | "A URI Template is a compact sequence of characters for describing a range of Uniform Resource Identifiers through variable expansion." | [RFC6570](http://tools.ietf.org/html/rfc6570)
`URI` | "A Uniform Resource Identifier (URI) provides a simple and extensible means for identifying a resource." | [RFC2986](http://tools.ietf.org/html/rfc3986)
